@@ -22,7 +22,7 @@
 #include "StaticDialog.h"
 
 #define LICENCE_TXT \
-TEXT("This program is free software; you can redistribute it and/or \
+L"This program is free software; you can redistribute it and/or \
 modify it under the terms of the GNU General Public License \
 as published by the Free Software Foundation; either \
 version 3 of the License, or at your option any later version.\r\n\
@@ -33,7 +33,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the \
 GNU General Public License for more details. \r\n\
 \r\n\
 You should have received a copy of the GNU General Public License \
-along with this program. If not, see <https://www.gnu.org/licenses/>.")
+along with this program. If not, see <https://www.gnu.org/licenses/>."
 
 
 class AboutDlg : public StaticDialog
